package com.example.p2pchatapplication.activity

import android.content.BroadcastReceiver
import android.content.ComponentName
import android.content.Context
import android.content.Intent
import android.content.IntentFilter
import android.content.ServiceConnection
import android.os.Bundle
import android.os.IBinder
import android.widget.Toast
import androidx.activity.enableEdgeToEdge
import androidx.appcompat.app.AppCompatActivity
import com.example.p2pchatapplication.database.MyDataManager
import com.example.p2pchatapplication.network.SocketClient
import com.example.p2pchatapplication.network.SocketManager
import com.example.p2pchatapplication.utils.Constants
import com.example.p2pchatapplication.utils.PreferenceManager
import com.example.p2pchatapplication.models.SocketClientMessage
import com.example.p2pchatapplication.models.User
import com.example.p2pchatapplication.services.MainService
import com.example.p2pchatapplication.utils.NetworkUtils
import org.java_websocket.client.WebSocketClient
import org.java_websocket.handshake.ServerHandshake
import org.json.JSONObject


class MainActivity : AppCompatActivity() {

    private lateinit var preferenceManager: PreferenceManager
    private lateinit var myDataManager: MyDataManager
    private lateinit var broadcastReceiver: BroadcastReceiver
    private lateinit var serverSocketClient: WebSocketClient
    private lateinit var mainService: MainService
    private var isBound = false

    private val connection: ServiceConnection = object : ServiceConnection {
        override fun onServiceConnected(className: ComponentName, service: IBinder) {
            val binder = service as MainService.LocalBinder
            mainService = binder.getService()
            isBound = true
            serverSocketClient = mainService.serverSocketClient

            val signedIn = preferenceManager.getBoolean(Constants.KEY_IS_SIGNED_IN)
            if (!signedIn) {
                startActivity(Intent(applicationContext, RegisterActivity::class.java))
            } else {
                // shit workaround
                Thread.sleep(500)
                register()
            }
        }

        override fun onServiceDisconnected(className: ComponentName) {
            isBound = false
        }
    }

    private fun doBindService() {
        bindService(
            Intent(this@MainActivity, MainService::class.java),
            connection, BIND_AUTO_CREATE
        )
    }

    override fun onStart() {
        super.onStart()
        doBindService()
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        startService(Intent(this, MainService::class.java))
        super.onCreate(savedInstanceState)
        enableEdgeToEdge()

        preferenceManager = PreferenceManager(applicationContext)
        myDataManager = MyDataManager.getInstance()

        broadcastReceiver = object: BroadcastReceiver() {
            override fun onReceive(context: Context?, intent: Intent?) {
                if (intent?.action == "REGISTER_SUCCESS") {
                    showToast("Register successful")
                    startActivity(Intent(applicationContext, ConversationsActivity::class.java))
                }
                else if (intent?.action == "REGISTER_FAILED") {
                    showToast("Register failed")
                    // connect when the connection to server is opened
                }
            }
        }

        val intentFilter = IntentFilter()
        intentFilter.addAction("REGISTER_SUCCESS")
        intentFilter.addAction("REGISTER_FAILED")
        intentFilter.addAction("SERVER_CONNECTED")
        registerReceiver(broadcastReceiver, intentFilter, RECEIVER_EXPORTED)
    }

    private fun register() {
        val username = preferenceManager.getString(Constants.KEY_USERNAME)
        val localIP = NetworkUtils(applicationContext).getLocalWifiIpAddress()
        val data = JSONObject()
        data.put("username", username)
        data.put("privatePort", Constants.WS_SERVER_PORT)
        data.put("privateAddress", localIP)

        val message = SocketClientMessage(Constants.MESSAGE_TOPIC_REGISTER, data).toJSONString()
        serverSocketClient.send(message)
        // wait for receiver to receive register confirmation
    }

    private fun showToast(message: String) {
        Toast.makeText(applicationContext, message, Toast.LENGTH_SHORT).show()
    }

    override fun onDestroy() {
        super.onDestroy()
        unregisterReceiver(broadcastReceiver)
        if (isBound) {
            unbindService(connection)
            isBound = false
        }
    }
}
