package com.example.p2pchatapplication.activity

import android.content.BroadcastReceiver
import android.content.ComponentName
import android.content.Context
import android.content.Intent
import android.content.IntentFilter
import android.content.ServiceConnection
import android.os.Bundle
import android.os.IBinder
import android.widget.Toast
import androidx.appcompat.app.AppCompatActivity
import com.example.p2pchatapplication.database.MyDataManager
import com.example.p2pchatapplication.databinding.ActivityRegisterBinding
import com.example.p2pchatapplication.network.SocketClient
import com.example.p2pchatapplication.network.SocketManager
import com.example.p2pchatapplication.utils.Constants
import com.example.p2pchatapplication.utils.PreferenceManager
import com.example.p2pchatapplication.models.SocketClientMessage
import com.example.p2pchatapplication.models.User
import com.example.p2pchatapplication.services.MainService
import com.example.p2pchatapplication.utils.NetworkUtils
import org.java_websocket.client.WebSocketClient
import org.json.JSONObject

class RegisterActivity : AppCompatActivity() {

    private lateinit var binding: ActivityRegisterBinding
    private lateinit var serverSocketClient: WebSocketClient
    private lateinit var broadcastReceiver: BroadcastReceiver
    private lateinit var mainService: MainService
    private var isBound = false

    private val connection: ServiceConnection = object : ServiceConnection {
        override fun onServiceConnected(className: ComponentName, service: IBinder) {
            val binder = service as MainService.LocalBinder
            mainService = binder.getService()
            isBound = true
            serverSocketClient = mainService.serverSocketClient
        }

        override fun onServiceDisconnected(className: ComponentName) {
            isBound = false
        }
    }

    private fun doBindService() {
        bindService(
            Intent(this@RegisterActivity, MainService::class.java),
            connection, BIND_AUTO_CREATE
        )
    }

    override fun onStart() {
        super.onStart()
        doBindService()
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityRegisterBinding.inflate(layoutInflater)
        setContentView(binding.root)
        setListeners()

        broadcastReceiver = object: BroadcastReceiver() {
            override fun onReceive(context: Context?, intent: Intent?) {
                if (intent?.action == "REGISTER_SUCCESS") {
                    showToast("Register successful")
                    startActivity(Intent(applicationContext, ConversationsActivity::class.java))
                }
                else if (intent?.action == "REGISTER_FAILED") {
                    showToast("Register failed")
                }
            }
        }
        val intentFilter = IntentFilter()
        intentFilter.addAction("REGISTER_SUCCESS")
        intentFilter.addAction("REGISTER_FAILED")
        registerReceiver(broadcastReceiver, intentFilter, RECEIVER_NOT_EXPORTED)
    }

    private fun setListeners() {
        binding.buttonRegister.setOnClickListener {
            if (isValidUsername()) {
                register(binding.inputUsername.getText().toString())
            } else {
                showToast("Missing username")
            }
        }
    }

    private fun showToast(message: String) {
        Toast.makeText(applicationContext, message, Toast.LENGTH_SHORT).show()
    }

    private fun register(username: String) {
        val localIP = NetworkUtils(applicationContext).getLocalWifiIpAddress()
        val data = JSONObject()
        data.put("username", username)
        data.put("privateAddress", localIP)
        data.put("privatePort", Constants.WS_SERVER_PORT)

        val message = SocketClientMessage(Constants.MESSAGE_TOPIC_REGISTER, data).toJSONString()
        serverSocketClient.send(message)
        // wait for receiver to receive register confirmation
    }

    private fun isValidUsername(): Boolean {
        if (binding.inputUsername.getText().toString().trim().isEmpty()) {
            showToast("Enter username")
            return false
        } else {
            return true
        }
    }

    override fun onDestroy() {
        super.onDestroy()
        unregisterReceiver(broadcastReceiver)
        if (isBound) {
            unbindService(connection)
            isBound = false
        }
    }
}
