package com.example.p2pchatapplication.network

import com.example.p2pchatapplication.utils.Constants
import org.java_websocket.client.WebSocketClient
import org.java_websocket.handshake.ServerHandshake
import java.net.URI

class SocketClient (serverUri: URI = URI(Constants.DISCOVERY_SERVER_ADDRESS), private val restartOnClose: Boolean) : WebSocketClient(serverUri) {

    private val RECONNECT_DELAY: Long = 2000 //ms

    private var onOpenHandler: (() -> Unit)? = null
    private var onMessageHandler: ((String?) -> Unit)? = null
    private var onErrorHandler: ((Exception?) -> Unit)?= null
    private var onCloseHandler: ((Int, String?, Boolean) -> Unit)? = null

    var connected = false

    fun setOnOpen(handler: () -> Unit) {
        onOpenHandler = handler
    }

    fun setOnMessage(handler: (String?) -> Unit) {
        onMessageHandler = handler
    }

    /*fun setOnError(handler:(Exception?) -> Unit) {
        onErrorHandler = handler
    }*/

    fun setOnClose(handler: (Int, String?, Boolean) -> Unit) {
        onCloseHandler = handler
    }

    override fun connect() {
        if (!connected) {
            super.connect()
            connected = true
        } else {
            println("already connected")
        }
    }

    override fun onOpen(handshakedata: ServerHandshake?) {
        println("LOCAL SOCKET ADDRESS: " + this.connection.localSocketAddress)
        println("REMOTE SOCKET ADDRESS: " + this.connection.remoteSocketAddress)
        onOpenHandler?.invoke()
    }

    override fun onMessage(message: String?) {
        println("received message: $message")
        onMessageHandler?.invoke(message)
    }

    override fun onClose(code: Int, reason: String?, remote: Boolean) {
        println("socket connection closed")
        connected = false
        onCloseHandler?.invoke(code, reason, remote)
        if (restartOnClose) {
            while (!connected) {
                println("Trying to connect to discovery server")
                this.reconnect()
                Thread.sleep(RECONNECT_DELAY)
            }
            println("connected to discovery server")
        }
    }

    override fun onError(ex: Exception?) {
        println(ex)
        onErrorHandler?.invoke(ex)
    }

}
